summaryrefslogtreecommitdiffstats
path: root/components
diff options
context:
space:
mode:
authorjif@chromium.org <jif@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-04-28 14:00:42 +0000
committerjif@chromium.org <jif@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-04-28 14:00:42 +0000
commit698fd44ce69464830d896f7d14105d30166fcfca (patch)
tree4f2f45a1f39df4e0014049bff09cd982979dfdb9 /components
parent84b07fbee5d68f25d29f9df8e606d502f440fcf3 (diff)
downloadchromium_src-698fd44ce69464830d896f7d14105d30166fcfca.zip
chromium_src-698fd44ce69464830d896f7d14105d30166fcfca.tar.gz
chromium_src-698fd44ce69464830d896f7d14105d30166fcfca.tar.bz2
Renamed FaviconHandlerDelegate to FaviconDriver.
Note: Currently FaviconTabHelper implements both FaviconClient and FaviconDriver. A follow up CL will create a ContentFaviconDriver class that implements FaviconDriver. FaviconTabHelper will then own an instance of the ContentFaviconDriver, instead of inheriting from FaviconDriver. BUG=362074 Review URL: https://codereview.chromium.org/255843002 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@266551 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'components')
-rw-r--r--components/favicon.gypi2
-rw-r--r--components/favicon/core/favicon_driver.h (renamed from components/favicon/core/favicon_handler_delegate.h)18
2 files changed, 10 insertions, 10 deletions
diff --git a/components/favicon.gypi b/components/favicon.gypi
index 9a67335..0d44dd3 100644
--- a/components/favicon.gypi
+++ b/components/favicon.gypi
@@ -9,7 +9,7 @@
'type': 'none',
'sources': [
'favicon/core/browser/favicon_client.h',
- 'favicon/core/favicon_handler_delegate.h',
+ 'favicon/core/favicon_driver.h',
],
},
],
diff --git a/components/favicon/core/favicon_handler_delegate.h b/components/favicon/core/favicon_driver.h
index ae70a18a..937ace8 100644
--- a/components/favicon/core/favicon_handler_delegate.h
+++ b/components/favicon/core/favicon_driver.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef COMPONENTS_FAVICON_CORE_FAVICON_HANDLER_DELEGATE_H_
-#define COMPONENTS_FAVICON_CORE_FAVICON_HANDLER_DELEGATE_H_
+#ifndef COMPONENTS_FAVICON_CORE_FAVICON_DRIVER_H_
+#define COMPONENTS_FAVICON_CORE_FAVICON_DRIVER_H_
class GURL;
@@ -12,16 +12,16 @@ namespace content {
class NavigationEntry;
}
-// This class provides a delegate interface for a FaviconHandler. It allows the
-// FaviconHandler to ask its delegate for information or notify its delegate
-// about changes.
-class FaviconHandlerDelegate {
+// Interface that allows Favicon core code to interact with its driver (i.e.,
+// obtain information from it and give information to it). A concrete
+// implementation must be provided by the driver.
+class FaviconDriver {
public:
// Returns the current NavigationEntry.
// TODO(jif): Abstract the NavigationEntry (crbug.com/359598).
virtual content::NavigationEntry* GetActiveEntry() = 0;
// Starts the download for the given favicon. When finished, the delegate
// will call OnDidDownloadFavicon() with the results.
// Returns the unique id of the download request. The id will be passed
// in OnDidDownloadFavicon().
@@ -31,7 +31,7 @@ class FaviconHandlerDelegate {
// is the only result. A |max_bitmap_size| of 0 means unlimited.
virtual int StartDownload(const GURL& url, int max_bitmap_size) = 0;
- // Notifies the delegate that the favicon for the active entry was updated.
+ // Notifies the driver that the favicon for the active entry was updated.
// |icon_url_changed| is true if a favicon with a different icon URL has
// been selected since the previous call to NotifyFaviconUpdated().
virtual void NotifyFaviconUpdated(bool icon_url_changed) = 0;
@@ -40,4 +40,4 @@ class FaviconHandlerDelegate {
virtual bool IsOffTheRecord() = 0;
};
-#endif // COMPONENTS_FAVICON_CORE_FAVICON_HANDLER_DELEGATE_H_
+#endif // COMPONENTS_FAVICON_CORE_FAVICON_DRIVER_H_
@@ -12,16 +12,16 @@ namespace content {
// TODO(jif): Abstract the NavigationEntry (crbug.com/359598).
virtual content::NavigationEntry* GetActiveEntry() = 0;
- // Starts the download for the given favicon. When finished, the delegate
+ // Starts the download for the given favicon. When finished, the driver
// will call OnDidDownloadFavicon() with the results.
// Returns the unique id of the download request. The id will be passed